Learn R Programming

rQCC (version 1.20.7)

Hodges-Lehmann: Hodges-Lehmann estimate

Description

Calculates the Hodges-Lehmann estimate.

Usage

HL(x, method = c("HL1", "HL2", "HL3"), na.rm = FALSE)

Arguments

x

a numeric vector of observations.

method

a character string specifying the estimator, must be one of "HL1" (default), "HL2" and "HL3".

na.rm

a logical value indicating whether NA values should be stripped before the computation proceeds.

Value

It returns a numeric value.

Details

HL computes the Hodges-Lehmann estimates (one of "HL1", "HL2", "HL3").

The Hodges-Lehmann (HL1) is defined as $$\mathrm{HL1} = \mathop{\mathrm{median}}_{i<j} \Big( \frac{X_i+X_j}{2} \Big)$$ where \(i,j=1,2,\ldots,n\).

The Hodges-Lehmann (HL2) is defined as $$\mathrm{HL2} = \mathop{\mathrm{median}}_{i \le j}\Big(\frac{X_i+X_j}{2} \Big).$$

The Hodges-Lehmann (HL3) is defined as $$\mathrm{HL3} = \mathop{\mathrm{median}}_{\forall(i,j)} \Big( \frac{X_i+X_j}{2} \Big).$$

References

Park, C., H. Kim, and M. Wang (2020). Investigation of finite-sample properties of robust location and scale estimators. Communications in Statistics - Simulation and Computation, To appear. https://doi.org/10.1080/03610918.2019.1699114

Hodges, J. L. and E. L. Lehmann (1963). Estimates of location based on rank tests. Annals of Mathematical Statistics, 34, 598--611.

See Also

mean{base} for calculating sample mean and median{stats} for calculating sample median.

finite.breakdown{rQCC} for calculating the finite-sample breakdown point.

Examples

Run this code
# NOT RUN {
x = c(0:10, 50)
HL(x, method="HL2")
# }

Run the code above in your browser using DataLab