Learn R Programming

rQCC (version 0.19.8.2)

Shamos: Shamos estimate (Fisher consistent)

Description

Calculates the Shamos estimate with the adjustment by a correction factor for the Fisher-consistency under the standard normal distribution.

Usage

shamos(x, constant=1.048358, na.rm = FALSE,  IncludeEqual=FALSE)

Arguments

x

a numeric vector of observations.

constant

Correction factor for the Fisher-consistency under the standard normal distribution

na.rm

a logical value indicating whether NA values should be stripped before the computation proceeds.

IncludeEqual

FALSE (default) calculates median of \(|X_i-X_j|\) with \(i < j\), while TRUE calculates median of \(|X_i-X_j|\) with \(i \le j\).

Value

shamos returns a numeric value.

Details

The Shamos estimator is defined as $$\textrm{Shamos}=\code{constant}\times\mathop{\mathrm{median}}_{i < j} \big(|X_i-X_j|\big)$$ where \(i,j=1,2,\ldots,n\). The default value (constant=1.048358) ensures the Fisher-consistency under the standard normal. Note that \(\code{constant}=1/\{\sqrt{2}\,\Phi^{-1}(3/4)\}\approx 1.048358\).

References

Park, C., H. Kim, and M. Wang (2019). Finite-sample properties of robust location and scale estimators. arXiv:1908.00462.

Shamos, M. I. (1976). Geometry and statistics: Problems at the interface. In Traub, J. F., editor, Algorithms and Complexity: New Directions and Recent Results, pages 251--280. Academic Press, New York.

L<U+00E8>vy-Leduc, C., Boistard, H., Moulines, E., Taqqu, M. S., and Reisen, V. A. (2011). Large sample behaviour of some well-known robust estimators under long-range dependence. Statistics, 45, 59--71.

See Also

rQCC::shamos.unbiased for robust finite-sample unbiased estimator for the standard deviation of a normal distribution.

stats::mad for calculating the sample median absolute deviation (MAD).

rQCC::finite.breakdown for calculating the finite-sample breakdown point.

Examples

Run this code
# NOT RUN {
x = c(0:10, 50)
shamos(x)
# }

Run the code above in your browser using DataLab