Learn R Programming

rQCC (version 0.19.8.2)

control.limits: Control limits factor for X-bar chart

Description

The conventional control limits of X-bar chart are given by $$\bar{\bar{X}} \pm A_3 \bar{S}.$$

A3.factor(n, "mad") and A3.factor(n, "shamos") are used when the median absolute deviation (MAD) and Shamos estimators are considered.

Usage

A3.factor(n, method=c("sd","mad","shamos"), sigma.factor=3)

Arguments

n

sample size (\(n \ge 1\)).

method

a character string specifying the estimator, must be one of "sd" (default), "mad" and "shamos."

sigma.factor

a factor for the standard deviation (\(\sigma\)). The American Standard uses "3*sigma" limits (0.27% false alarm rate), while the British Standard uses "3.09*sigma" limits (0.20% false alarm rate).

Value

A3.factor calculates the control limits factor for X-bar chart.

References

ASTM (2018). Manual on Presentation of Data and Control Chart Analysis (9th edition). American Society for Testing and Materials, West Conshohocken, PA.

Examples

Run this code
# NOT RUN {
# The American 3*sigma limits with the sample standard deviation.
A3.factor(n=10, method="sd")

# The British 3.09*sigma limits with the Shamos estimator.
A3.factor(n=10, method="shamos", sigma.factor=3.09)
# }

Run the code above in your browser using DataLab