Learn R Programming

rQCC (version 0.19.8.2)

correction.factor: Finite-sample correction factor for the standard deviation

Description

Finite-sample correction factor for the standard deviation (\(\sigma\)) under the normal distribution.

Usage

c4.factor(n, method=c("sd","mad","shamos"))

Arguments

n

sample size (\(n \ge 1\)).

method

a character string specifying the estimator, must be one of "sd" (default), "mad" and "shamos."

Value

c4.factor computes the finite-sample correction factor when the sample standard deviations, the sample median absolute deviation (MAD) and Shamos estimates are used.

Details

The conventional sample standard deviation, median absolute deviation (MAD) and Shamos estimators are Fisher-consistent under the normal distribution, but they are not unbiased with a sample of finite size.

An unbiased estimator of (\(\sigma\)) with the sample standard deviation (\(s\)) is given by sd(x)/c4.factor(length(x), method="sd") where \(n\) is the sample size.

When the median absolute deviation (stats::mad) estimator is used, an unbiased estimator of (\(\sigma\)) is given by mad(x)/c4.factor(length(x), method="mad").

Using the Shamos estimator (rQCC::shamos), an unbiased estimator of (\(\sigma\)) is given by shamos(x)/c4.factor(length(x), method="shamos").

Note that the formula for the correction factor \(c_4(n)\) is given by $$c_4(n) = \sqrt{\frac{2}{n-1}}\cdot\frac{\Gamma(n/2)}{\Gamma((n-1)/2)}.$$

The finite-sample correction factors for the median absolute deviation (MAD) and Shamos estimators are obtained for \(n=1,2,\ldots,10\) using the extensive Monte Carlo simulation with 1E07 replicates. For the case of \(n > 100\), they are obtained using the method of Hayes (2014).

References

Park, C., H. Kim, and M. Wang (2019). Finite-sample properties of robust location and scale estimators. arXiv:1908.00462.

Shamos, M. I. (1976). Geometry and statistics: Problems at the interface. In Traub, J. F., editor, Algorithms and Complexity: New Directions and Recent Results, pages 251--280. Academic Press, New York.

Hayes, K. (2014). Finite-sample bias-correction factors for the median absolute deviation. Communications in Statistics: Simulation and Computation, 43, 2205--2212.

See Also

stats::mad for the Fisher-consistent median absolute deviation (MAD) estimator for the standard deviation (\(\sigma\)) of a normal distribution.

rQCC::mad.unbiased for finite-sample unbiased median absolute deviation (MAD) estimator for the standard deviation (\(\sigma\)) of a normal distribution.

rQCC::shamos for the Fisher-consistent Shamos estimator for the standard deviation (\(\sigma\)) of a normal distribution.

rQCC::shamos.unbiased for finite-sample unbiased Shamos estimator for the standard deviation (\(\sigma\)) of a normal distribution.

rQCC::n.times.eBias.of.mad for the values of the empirical biases of the median absolute deviation (MAD) estimator under the standard normal distribution.

rQCC::n.times.eBias.of.shamos for the values of the empirical biases of the Shamos estimator under the standard normal distribution.

Examples

Run this code
# NOT RUN {
c4.factor(n=10, method="sd")

c4.factor(n=10, method="mad")

c4.factor(n=10, method="shamos")
# }

Run the code above in your browser using DataLab