Learn R Programming

rQCC (version 1.20.7)

empirical.variance: Empirical variances of robust estimators

Description

Provides the empirical variances of the median, Hodges-Lehmann (HL1, HL2, HL3) median absolute deviation (MAD) and Shamos estimators.

Usage

evar (n, method = c("median", "HL1", "HL2", "HL3", "mad", "shamos"))

Arguments

n

sample size (\(n \ge 1\)).

method

a character string specifying the estimator, must be one of "median" (default), "HL1", "HL2", "HL3", "mad", and "shamos".

Value

It returns a numeric value.

Details

The empirical variances for \(n=1,2,\ldots,100\) are obtained using the extensive Monte Carlo simulation with 1E07 replicates. For the case of \(n > 100\), they are obtained using the method of Hayes (2014).

evar computes the empirical variance of a specific estimator (one of "median", "HL1", "HL2", "HL3", "mad", and "shamos") when a random sample is from the standard normal distribution.

References

Park, C., H. Kim, and M. Wang (2020). Investigation of finite-sample properties of robust location and scale estimators. Communications in Statistics - Simulation and Computation, To appear. https://doi.org/10.1080/03610918.2019.1699114

Hayes, K. (2014). Finite-sample bias-correction factors for the median absolute deviation. Communications in Statistics: Simulation and Computation, 43, 2205--2212.

See Also

RE{rQCC} for the relative efficiency. n.times.eVar.of.HL1{rQCC} for the empirical variance of the HL1 estimator (times n). n.times.eVar.of.HL2{rQCC} for the empirical variance of the HL2 estimator (times n). n.times.eVar.of.HL3{rQCC} for the empirical variance of the HL3 estimator (times n). n.times.eVar.of.mad{rQCC} for the empirical variance of the MAD estimator (times n). n.times.eVar.of.median{rQCC} for the empirical variance of the median estimator (times n). n.times.eVar.of.shamos{rQCC} for the empirical variance of the Shamos estimator (times n).

Examples

Run this code
# NOT RUN {
# Empirical variance of the Hodges-Lehmann estimator (HL2) under the standard normal distribution.
evar (n=10, method="HL2")
# }

Run the code above in your browser using DataLab