Learn R Programming

rQCC (version 0.19.8.2)

factor.for.squared.mad: Finite-sample correction factor for the squared MAD (median absolute deviation) estimator under the normal distribution

Description

Finite-sample correction factor for the squared median absolute deviation (MAD) estimator under the normal distribution with a sample of size n. Note that the conventional squared median absolute deviation (MAD) estimator is Fisher-consistent under the normal distribution, but it is not unbiased with a sample of finite size.

The finite-sample correction factors for \(n=1,2,\ldots,10\) are obtained using the extensive Monte Carlo simulation with 1E07 replicates. For the case of \(n > 100\), they are obtained using the method of Hayes (2014).

Usage

w5.for.mad2(n)

Arguments

n

sample size (\(n \ge 1\)).

Value

w5.for.mad2 calculates the finite-sample correction factor for the variance (\(\sigma^2\)) under the normal distribution.

References

Park, C., H. Kim, and M. Wang (2019). Finite-sample properties of robust location and scale estimators. arXiv:1908.00462.

Hayes, K. (2014). Finite-sample bias-correction factors for the median absolute deviation. Communications in Statistics: Simulation and Computation, 43, 2205--2212.

See Also

rQCC::mad2.unbiased for robust finite-sample unbiased squared median absolute deviation (MAD) estimator for the variance (\(\sigma^2\)) of a normal distribution.

rQCC::shamos2.unbiased for robust finite-sample unbiased squared Shamos estimator for the variance (\(\sigma^2\)) of a normal distribution.

stats::mad for calculating the sample median absolute deviation (MAD).

rQCC::shamos for calculating the sample Shamos estimate.

Examples

Run this code
# NOT RUN {
w5.for.mad2(n=10)
# }

Run the code above in your browser using DataLab