Finite-sample correction factor for the squared Shamos estimator under the normal distribution with a sample of size n. Note that the conventional squared Shamos estimator is Fisher-consistent under the normal distribution, but it is not unbiased with a sample of finite size.
The finite-sample correction factors for \(n=1,2,\ldots,10\) are obtained using the extensive Monte Carlo simulation with 1E07 replicates. For the case of \(n > 100\), they are obtained using the method of Hayes (2014).
w6.for.shamos2(n)sample size (\(n \ge 1\)).
w6.for.shamos2 calculates the finite-sample correction factor
for the variance (\(\sigma^2\)) under the normal distribution.
Park, C., H. Kim, and M. Wang (2019). Finite-sample properties of robust location and scale estimators. arXiv:1908.00462.
Hayes, K. (2014). Finite-sample bias-correction factors for the median absolute deviation. Communications in Statistics: Simulation and Computation, 43, 2205--2212.
rQCC::shamos2.unbiased for robust finite-sample unbiased squared Shamos estimator
for the variance (\(\sigma^2\)) of a normal distribution.
rQCC::mad2.unbiased for robust finite-sample unbiased squared
median absolute deviation (MAD) estimator
for the variance (\(\sigma^2\)) of a normal distribution.
stats::mad for calculating the sample median absolute deviation (MAD).
rQCC::shamos for calculating the sample Shamos estimate.
# NOT RUN {
w6.for.shamos2(n=10)
# }
Run the code above in your browser using DataLab