Learn R Programming

rQCC (version 0.19.8.2)

n.times.eBias.of.mad: Empirical biases of the MAD (median absolute deviation) estimator (times n)

Description

n times the empirical biases of the median absolute deviation(MAD) estimator under the standard normal distribution, where n is the sample size and n is from 1 to 100. For the median absolute deviation(MAD) estimates, mad{stats} is used. They are obtained using the extensive Monte Carlo simulation with 1E07 replicates.

Usage

n.times.eBias.of.mad

Arguments

Value

n.times.eBias.of.mad returns a vector of 100 values.

Format

This data frame contains 100 values.

References

Park, C., H. Kim, and M. Wang (2019). Finite-sample properties of robust location and scale estimators. arXiv:1908.00462.