Learn R Programming

rQCC (version 0.19.8.2)

n.times.eVar.of.median: Empirical variances of the median estimator (times n)

Description

n times the empirical variances of the median estimator under the standard normal distribution, where \(n\) is the sample size and \(n\) is from 1 to 100. For the median estimates, median{stats} is used. They are obtained using the extensive Monte Carlo simulation with 1E07 replicates.

Usage

n.times.eVar.of.median

Arguments

Value

n.times.eVar.of.median returns a vector of 100 values.

Format

This data frame contains 100 values.

References

Park, C., H. Kim, and M. Wang (2019). Finite-sample properties of robust location and scale estimators. arXiv:1908.00462.