Learn R Programming

rQCC (version 0.19.8.2)

n.times.eVar.of.shamos: Empirical variances of the Shamos estimator (times n)

Description

n times the empirical variances of the Shamos estimator under the standard normal distribution, where \(n\) is the sample size and \(n\) is from 1 to 100. Note that the Fisher-consistent Shamos estimator is used. The empirical variances are obtained using the extensive Monte Carlo simulation with 1E07 replicates.

Usage

n.times.eVar.of.shamos

Arguments

Value

n.times.eVar.of.shamos returns a vector of 100 values.

Format

This data frame contains 100 values.

References

Park, C., H. Kim, and M. Wang (2019). Finite-sample properties of robust location and scale estimators. arXiv:1908.00462.

Shamos, M. I. (1976). Geometry and statistics: Problems at the interface. In Traub, J. F., editor, Algorithms and Complexity: New Directions and Recent Results, pages 251--280. Academic Press, New York.

L<U+00E8>vy-Leduc, C., Boistard, H., Moulines, E., Taqqu, M. S., and Reisen, V. A. (2011). Large sample behaviour of some well-known robust estimators under long-range dependence. Statistics, 45, 59--71.