Learn R Programming

rQCC (version 1.20.7)

relative.efficiency: Relative efficiency (RE)

Description

Calculates the relative efficiency value of the mean, median and Hodges-Lehmann (HL1, HL2, HL3) estimators with respect to the sample mean and that of the standard deviation, range, median absolute deviation (MAD) and Shamos estimators with respect to the sample standard deviation. Note that the relative efficiency value of the mean and the standard deviation is always one by definition.

For the case of the sample mean, standard deviation and range, it is possible to derive their variances in analytic form, but, for the other case, it may be impossible. In this case, the variances with \(n=1,2,\ldots,100\) are obtained using the extensive Monte Carlo simulation with 1E07 replicates. For \(n > 100\), the variances are approximated based on the method of Hayes (2014).

To obtain the relative efficiency value of the unbiased scale estimators, use correction=TRUE option. Note that the location estimators ("mean", "median", "HL1", "HL2", "HL3") are unbiased.

Usage

RE (n, method = c("mean", "median","HL1","HL2","HL3", "sd", "range","mad","shamos"),
       correction = FALSE)

Arguments

n

sample size (\(n \ge 1\)).

correction

a finite-sample bias correction. TRUE adjusts a finite-sample bias correction using A3.factor function.

method

a character string specifying the estimator, must be one of "mean" (default), "median", "HL1", "HL2", "HL3", "range", "mad", and "shamos".

Value

It returns a numeric value.

Details

RE calculates the relative efficiency value of a location estimator ("median", "HL1", "HL2", "HL3") with respect to the sample mean and that of a scale estimator ("range", "mad", "shamos") with respect to the sample standard deviation.

Note that the relative efficiency (RE) of \(\hat{\theta}_2\) with respect to \(\hat{\theta}_1\) is defined as $$\mathrm{RE}(\hat{\theta}_2 | \hat{\theta}_1) =\frac{\mathrm{Var}(\hat{\theta}_1)}{\mathrm{Var}(\hat{\theta}_2)}.$$

References

Park, C., H. Kim, and M. Wang (2020). Investigation of finite-sample properties of robust location and scale estimators. Communications in Statistics - Simulation and Computation, To appear. https://doi.org/10.1080/03610918.2019.1699114

Hayes, K. (2014). Finite-sample bias-correction factors for the median absolute deviation. Communications in Statistics: Simulation and Computation, 43, 2205--2212.

See Also

n.times.eVar.of.HL1{rQCC} for the empirical variance of the HL1 estimator (times \(n\)). n.times.eVar.of.HL2{rQCC} for the empirical variance of the HL2 estimator (times \(n\)). n.times.eVar.of.HL3{rQCC} for the empirical variance of the HL3 estimator (times \(n\)). n.times.eVar.of.mad{rQCC} for the empirical variance of the MAD estimator (times \(n\)). n.times.eVar.of.median{rQCC} for the empirical variance of the median estimator (times \(n\)). n.times.eVar.of.shamos{rQCC} for the empirical variance of the Shamos estimator (times \(n\)).

Examples

Run this code
# NOT RUN {
# The RE of the Hodges-Lehmann (HL2) estimator 
#  with respect to the sample standard deviation under the normal distribution.
RE(n=5, method="HL2")

# RE of the Shamos estimator 
# with respect to the sample standard deviation under the normal distribution.
RE(n=5, method="shamos")

# RE of the unbiased Shamos estimator 
# with respect to the unbiased sample standard deviation under the normal distribution.
RE(n=5, method="shamos", correction=TRUE) 

# RE of the range (maximum minus minimum)
# with respect to the sample standard deviation under the normal distribution.
RE(n=6, method="range")

# RE of the unbiased range ( (maximum - minimum) / d2 )
# with respect to the unibased sample standard deviation under the normal distribution.
RE(n=6, method="range", correction=TRUE)
# }

Run the code above in your browser using DataLab