Learn R Programming

rQCC (version 0.19.8.2)

unbiased.shamos: Unbiased Shamos estimate

Description

Calculates the unbiased Shamos estimate under the normal distribution with the adjustment by a the Fisher-consistency factor and a finite-sample correction factor.

Usage

shamos.unbiased(x, constant=1.048358, na.rm = FALSE,  IncludeEqual=FALSE)

Arguments

x

a numeric vector of observations.

constant

Correction factor for the Fisher-consistency under the standard normal distribution

na.rm

a logical value indicating whether NA values should be stripped before the computation proceeds.

IncludeEqual

FALSE (default) calculates median of \(|X_i-X_j|\) with \(i < j\), while TRUE calculates median of \(|X_i-X_j|\) with \(i \le j\).

Value

hamos.unbiased returns a numeric value.

Details

The unbiased Shamos is defined as $$\textrm{Shamos}=\code{constant}\times\mathop{\mathrm{median}}_{i < j} \big(|X_i-X_j|\big)/{c_6(n)}$$ where \(i,j=1,2,\ldots,n\) and the unbiasing factor with a sample of finite size, \(c_6(n)\), is calculated by rQCC::c4.factor with method="shamos" option.

The default value (constant=1.048358) ensures the Fisher-consistency under the standard normal. Note that \(\code{constant}=1/\{\sqrt{2}\,\Phi^{-1}(3/4)\}\approx 1.048358\).

References

Park, C., H. Kim, and M. Wang (2019). Finite-sample properties of robust location and scale estimators. arXiv:1908.00462.

Shamos, M. I. (1976). Geometry and statistics: Problems at the interface. In Traub, J. F., editor, Algorithms and Complexity: New Directions and Recent Results, pages 251--280. Academic Press, New York.

L<U+00E8>vy-Leduc, C., Boistard, H., Moulines, E., Taqqu, M. S., and Reisen, V. A. (2011). Large sample behaviour of some well-known robust estimators under long-range dependence. Statistics, 45, 59--71.

See Also

rQCC::shamos for robust Fisher-consistent estimator for the standard deviation of a normal distribution.

rQCC::c4.factor for finite-sample correction factor for the standard deviation under the normal distribution.

stats::mad for calculating the sample median absolute deviation (MAD).

rQCC::finite.breakdown for calculating the finite-sample breakdown point.

Examples

Run this code
# NOT RUN {
x = c(0:10, 50)

# Unbiased Shamos
shamos.unbiased(x)

# Fisher-consistent Shamos
shamos(x)
# }

Run the code above in your browser using DataLab