Learn R Programming

rQCC (version 0.19.8.2)

unbiased.squared.mad: Unbiased squared MAD (median absolute deviation) estimate

Description

Calculates the unbiased squared median absolute deviation(MAD) estimate under the normal distribution which is adjusted by the Fisher-consistency and finite-sample correction factors.

Usage

mad2.unbiased(x, center = median(x), constant=1.4826, na.rm = FALSE)

Arguments

x

a numeric vector of observations.

center

Optionally, the centre: defaults to the median.

constant

Correction factor for the Fisher-consistency under the standard normal distribution

na.rm

a logical value indicating whether NA values should be stripped before the computation proceeds.

Value

mad2.unbiased returns a numeric value.

Details

The unbiased squared median absolute deviation(MAD) is defined as the squared stats::mad divided by \(w_5(n)\) where the finite-sample correction factor \(w_5(n)\) is calculated by rQCC::w5.for.mad2. The default value (constant=1.4826) ensures the Fisher-consistency under the standard normal. Note that the square of the conventional median absolute deviation(MAD) estimator is Fisher-consistent for the variance (\(\sigma^2\)) under the normal distribution, but it is not unbiased with a sample of finite size.

References

Park, C., H. Kim, and M. Wang (2019). Finite-sample properties of robust location and scale estimators. arXiv:1908.00462.

Hampel, F. R. (1974). The influence curve and its role in robust estimation. Journal of the American Statistical Association, 69, 383--393.

See Also

rQCC::w5.for.mad2 for finite-sample correction factor for the squared median absolute deviation(MAD) estimator for the variance (\(\sigma^2\)) under the normal distribution.

rQCC::mad.unbiased for robust finite-sample unbiased median absolute deviation(MAD) estimator for the standard deviation (\(\sigma\)) of a normal distribution.

rQCC::finite.breakdown for calculating the finite-sample breakdown point.

Examples

Run this code
# NOT RUN {
x = c(0:10, 50)

# Unbiased squared median absolute deviation(MAD)
mad2.unbiased(x)

# Fisher-consistent squared median absolute deviation(MAD)
mad(x)^2
# }

Run the code above in your browser using DataLab