The empirical variances for \(n=1,2,\ldots,100\) are obtained
using the extensive Monte Carlo simulation with 1E07 replicates.
For the case of \(n > 100\), they are obtained using the method of Hayes (2014).
evar computes the empirical variance of a specific
estimator (one of "median", "HL1", "HL2", "HL3", "mad",
and "shamos")
when a random sample is from the standard normal distribution.