a character string specifying the estimator, must be
one of "median" (default), "HL1", "HL2", "HL3", "mad", and "shamos."
Value
evar computes the empirical varinace of a specific
estimator (one of "median", "HL1", "HL2", "HL3", "mad", and "shamos")
when a random sample is from the standard normal distribution.
Details
The empirical variances for \(n=1,2,\ldots,10\) are obtained
using the extensive Monte Carlo simulation with 1E07 replicates.
For the case of \(n > 100\), they are obtained using the method of Hayes (2014).
References
Park, C., H. Kim, and M. Wang (2019).
Finite-sample properties of robust location and scale estimators.
arXiv:1908.00462.
Hayes, K. (2014).
Finite-sample bias-correction factors for the median absolute deviation.
Communications in Statistics: Simulation and Computation,
43, 2205--2212.
See Also
rQCC::RE for the relative efficiency.
rQCC::n.times.eVar.of.HL1 for the empirical variance of the HL1 estimator (times n).
rQCC::n.times.eVar.of.HL2 for the empirical variance of the HL2 estimator (times n).
rQCC::n.times.eVar.of.HL3 for the empirical variance of the HL3 estimator (times n).
rQCC::n.times.eVar.of.mad for the empirical variance of the MAD estimator (times n).
rQCC::n.times.eVar.of.median for the empirical variance of the median estimator (times n).
rQCC::n.times.eVar.of.shamos for the empirical variance of the Shamos estimator (times n).