Calculates the finite-sample breakdown point of the mean, median, Hodges-Lehmann estimators (HL1, HL2, HL3), standard deviation, range, MAD (median absolute deviation) and Shamos estimators. Note that for the case of the mean, standard deviation and range, the finite-sample breakdown points are always zero.
finite.breakdown(n,
method=c("mean","median","HL1","HL2","HL3","sd","range","mad","shamos") )sample size (\(n \ge 1\)).
a character string specifying the estimator, must be
one of "mean" (default), "median", "HL1", "HL2", "HL3",
"sd", "range", "mad", and "shamos".
It returns a numeric value.
finite.breakdown gives the finite-sample breakdown point
of the specified estimator.
The Hodges-Lehmann (HL1) is defined as $$\mathrm{HL1} = \mathop{\mathrm{median}}_{i<j} \Big( \frac{X_i+X_j}{2} \Big)$$ where \(i,j=1,2,\ldots,n\).
The Hodges-Lehmann (HL2) is defined as $$\mathrm{HL2} = \mathop{\mathrm{median}}_{i \le j}\Big(\frac{X_i+X_j}{2} \Big).$$
The Hodges-Lehmann (HL3) is defined as $$\mathrm{HL3} = \mathop{\mathrm{median}}_{\forall(i,j)} \Big( \frac{X_i+X_j}{2} \Big).$$
Park, C., H. Kim, and M. Wang (2020). Investigation of finite-sample properties of robust location and scale estimators. Communications in Statistics - Simulation and Computation, To appear. https://doi.org/10.1080/03610918.2019.1699114
Hodges, Jr., J. L. (1967). Efficiency in normal samples and tolerance of extreme values for some estimates of location. Proceedings of the Fifth Berkeley Symposium on Mathematical Statistics and Probability, Vol. 1, 163--186. University of California Press, Berkeley.
Hampel, F. R., Ronchetti, E., Rousseeuw, P. J., and Stahel, W. A. (1986). Robust Statistics: The Approach Based on Influence Functions, Subsection 2.2a. John Wiley & Sons, New York.
HL{rQCC} for the Hodges-Lehmann estimate.
# NOT RUN {
# finite-sample breakdown point of the Hodges-Lehmann (HL1) with size n=10.
finite.breakdown(n=10, method="HL2")
# }
Run the code above in your browser using DataLab