\(n\) times the empirical biases of the median absolute deviation (MAD)
and Shamos estimators
under the standard normal distribution, where \(n\) is the sample size
and \(n\) is from 1 to 100.
For the MAD estimator, mad{stats} is used.
For the Shamos estimator, the Fisher-consistent Shamos estimator, shamos{rQCC}, is used.
These estimators are not unbiased with a finite sample. The empirical biases are obtained using the extensive Monte Carlo simulation with 1E07 replicates.
n.times.eBias.of.madn.times.eBias.of.shamos
They return a vector of 100 values.
Park, C., H. Kim, and M. Wang (2020). Investigation of finite-sample properties of robust location and scale estimators. Communications in Statistics - Simulation and Computation, To appear. https://doi.org/10.1080/03610918.2019.1699114
Shamos, M. I. (1976). Geometry and statistics: Problems at the interface. In Traub, J. F., editor, Algorithms and Complexity: New Directions and Recent Results, pages 251--280. Academic Press, New York.
L<U+00E8>vy-Leduc, C., Boistard, H., Moulines, E., Taqqu, M. S., and Reisen, V. A. (2011). Large sample behaviour of some well-known robust estimators under long-range dependence. Statistics, 45, 59--71.