n times the empirical biases of the median absolute deviation(MAD) estimator under the standard normal distribution, where n is the sample size and n is from 1 to 100. For the median absolute deviation(MAD) estimates, mad{stats} is used. They are obtained using the extensive Monte Carlo simulation with 1E07 replicates.
n.times.eBias.of.madn.times.eBias.of.mad returns a vector of 100 values.
This data frame contains 100 values.
Park, C., H. Kim, and M. Wang (2019). Finite-sample properties of robust location and scale estimators. arXiv:1908.00462.