# NOT RUN {
# The RE of the Hodges-Lehmann (HL2) estimator
# with respect to the sample standard deviation under the normal distribution.
RE(n=5, method="HL2")
# RE of the Shamos estimator
# with respect to the sample standard deviation under the normal distribution.
RE(n=5, method="shamos")
# RE of the unbiased Shamos estimator
# with respect to the unbiased sample standard deviation under the normal distribution.
RE(n=5, method="shamos", correction=TRUE)
# RE of the range (maximum minus minimum)
# with respect to the sample standard deviation under the normal distribution.
RE(n=6, method="range")
# RE of the unbiased range ( (maximum - minimum) / d2 )
# with respect to the unibased sample standard deviation under the normal distribution.
RE(n=6, method="range", correction=TRUE)
# }
Run the code above in your browser using DataLab