Learn R Programming

rQCC (version 0.19.8.2)

relative.efficiency: Relative efficiency (RE)

Description

Calculates the relative efficiency of the median and Hodges-Lehmann (HL1, HL2, HL3) estimators with respect to the sample mean and that of the median absolute deviation (MAD) and Shamos estimators with respect to the sample standard deviation.

The relative efficiencies for \(n=1,2,\ldots,10\) are obtained using the extensive Monte Carlo simulation with 1E07 replicates. For the case of \(n > 100\), they are obtained based on the method of Hayes (2014).

Usage

RE (n, method = c("median", "HL1", "HL2", "HL3", "mad", "shamos"))

Arguments

n

sample size (\(n \ge 1\)).

method

a character string specifying the estimator, must be one of "median" (default), "HL1", "HL2", "HL3", "mad", and "shamos."

Value

RE calculates the relative efficiency of a location estimator ("median", "HL1", "HL2", "HL3") with respect to the sample mean and that of a scale estimator ("mad", "shamos") with respect to the sample standard deviation.

Details

The relative efficiency (RE) of \(\hat{\theta}_2\) with respect to \(\hat{\theta}_1\) is defined as $$\mathrm{RE}(\hat{\theta}_2 | \hat{\theta}_1) =\frac{\mathrm{Var}(\hat{\theta}_1)}{\mathrm{Var}(\hat{\theta}_2)}.$$

References

Park, C., H. Kim, and M. Wang (2019). Finite-sample properties of robust location and scale estimators. arXiv:1908.00462.

Hayes, K. (2014). Finite-sample bias-correction factors for the median absolute deviation. Communications in Statistics: Simulation and Computation, 43, 2205--2212.

See Also

rQCC::n.times.eVar.of.HL1 for the empirical variance of the HL1 estimator (times n). rQCC::n.times.eVar.of.HL2 for the empirical variance of the HL2 estimator (times n). rQCC::n.times.eVar.of.HL3 for the empirical variance of the HL3 estimator (times n). rQCC::n.times.eVar.of.mad for the empirical variance of the MAD estimator (times n). rQCC::n.times.eVar.of.median for the empirical variance of the median estimator (times n). rQCC::n.times.eVar.of.shamos for the empirical variance of the Shamos estimator (times n).

Examples

Run this code
# NOT RUN {
# The relative efficiency of the Hodges-Lehmann (HL2) estimator
#     with respect to the sample standard deviation under the normal distribution.

RE(n=10, method="HL2")
# }

Run the code above in your browser using DataLab