Calculates the unbiased Shamos estimate under the normal distribution with the adjustment by a the Fisher-consistency factor and a finite-sample correction factor.
shamos.unbiased(x, constant=1.048358, na.rm = FALSE, IncludeEqual=FALSE)a numeric vector of observations.
Correction factor for the Fisher-consistency under the standard normal distribution
a logical value indicating whether NA values should be stripped before the computation proceeds.
FALSE (default) calculates median of
\(|X_i-X_j|\) with \(i < j\),
while TRUE calculates median of \(|X_i-X_j|\) with \(i \le j\).
hamos.unbiased returns a numeric value.
The unbiased Shamos is defined as
$$\textrm{Shamos}=\code{constant}\times\mathop{\mathrm{median}}_{i < j} \big(|X_i-X_j|\big)/{c_6(n)}$$
where \(i,j=1,2,\ldots,n\) and the unbiasing factor with a sample of finite size,
\(c_6(n)\), is calculated by rQCC::c4.factor with method="shamos" option.
The default value (constant=1.048358) ensures the Fisher-consistency under the standard normal.
Note that
\(\code{constant}=1/\{\sqrt{2}\,\Phi^{-1}(3/4)\}\approx 1.048358\).
Park, C., H. Kim, and M. Wang (2019). Finite-sample properties of robust location and scale estimators. arXiv:1908.00462.
Shamos, M. I. (1976). Geometry and statistics: Problems at the interface. In Traub, J. F., editor, Algorithms and Complexity: New Directions and Recent Results, pages 251--280. Academic Press, New York.
L<U+00E8>vy-Leduc, C., Boistard, H., Moulines, E., Taqqu, M. S., and Reisen, V. A. (2011). Large sample behaviour of some well-known robust estimators under long-range dependence. Statistics, 45, 59--71.
rQCC::shamos for robust Fisher-consistent estimator
for the standard deviation of a normal distribution.
rQCC::c4.factor for finite-sample correction factor for the standard deviation
under the normal distribution.
stats::mad for calculating the sample median absolute deviation (MAD).
rQCC::finite.breakdown for calculating the finite-sample breakdown point.
# NOT RUN {
x = c(0:10, 50)
# Unbiased Shamos
shamos.unbiased(x)
# Fisher-consistent Shamos
shamos(x)
# }
Run the code above in your browser using DataLab