Calculates the unbiased squared Shamos estimate under the normal distribution which is adjusted by the Fisher-consistency and finite-sample correction factors.
shamos2.unbiased(x, constant=1.048358, na.rm = FALSE, IncludeEqual=FALSE)a numeric vector of observations.
Correction factor for the Fisher-consistency under the standard normal distribution
a logical value indicating whether NA values should be stripped before the computation proceeds.
FALSE (default) calculates median of
\(|X_i-X_j|\) with \(i < j\),
while TRUE calculates median of \(|X_i-X_j|\) with \(i \le j\).
shamos2.unbiased returns a numeric value.
The unbiased squared Shamos estimator is defined as the
squared rQCC::shamos divided by \(w_6(n)\)
where the finite-sample correction factor \(w_6(n)\)
is calculated by rQCC::w6.for.shamos2.
The default value (constant=1.048358) ensures the Fisher-consistency under the standard normal.
Note that the square of the conventional Shamos estimator is
Fisher-consistent for the variance (\(\sigma^2\)) under the normal distribution, but
it is not unbiased with a sample of finite size.
Park, C., H. Kim, and M. Wang (2019). Finite-sample properties of robust location and scale estimators. arXiv:1908.00462.
Shamos, M. I. (1976). Geometry and statistics: Problems at the interface. In Traub, J. F., editor, Algorithms and Complexity: New Directions and Recent Results, pages 251--280. Academic Press, New York.
L<U+00E8>vy-Leduc, C., Boistard, H., Moulines, E., Taqqu, M. S., and Reisen, V. A. (2011). Large sample behaviour of some well-known robust estimators under long-range dependence. Statistics, 45, 59--71.
rQCC::w6.for.shamos2 for finite-sample correction factor for the squared Shamos estimator
for the variance (\(\sigma^2\)) under the normal distribution.
rQCC::shamos.unbiased for robust finite-sample unbiased Shamos estimator
for the standard deviation (\(\sigma\)) of a normal distribution.
rQCC::finite.breakdown for calculating the finite-sample breakdown point.
# NOT RUN {
x = c(0:10, 50)
# Unbiased squared Shamos
shamos2.unbiased(x)
# Fisher-consistent squared Shamos
shamos(x)^2
# }
Run the code above in your browser using DataLab